@@ -1,22 +1,15 @@
-from struct import unpack
 import socket
-from asyncio import shield, wait_for, wait
+from asyncio import wait_for
 import asyncio
-import math
 import errno
-from functools import reduce
-import os
-import sys
-import time
-import datetime
-
-from pathlib import Path
 from basic_logtools.filelog import LogFile
 
-from networktools.time import timestamp, now
+from networktools.time import now
 from networktools.library import my_random_string
 
 from networktools.colorprint import rprint, bprint
+from networktools.path import home_path
+
 
 class BaseProtocol:
     """ Class to connect to tcp port and parse GSOF messages """
@@ -24,11 +17,11 @@ class BaseProtocol:
 
     def __init__(self, **kwargs):
         station = kwargs.get('code')
-        sock = kwargs.get('sock')
+        self.sock = kwargs.get('sock')
         self.timeout = kwargs.get('timeout', 1)
         self.raise_timeout = kwargs.get('raise_timeout', False)
-        self.raise_incompleteread = kwargs.get("raise_incomplete_read",False)
-        self.max_try = kwargs.get("max_try",3600)        
+        self.raise_incompleteread = kwargs.get("raise_incomplete_read", False)
+        self.max_try = kwargs.get("max_try", 3600)
         self.host = kwargs.get('host')
         self.port = kwargs.get('port')
         self.sock = self.create_socket(None)
@@ -44,7 +37,9 @@ class BaseProtocol:
         # manage asyncronous clients
         self.idc = []
         self.clients = {}
-        log_path = kwargs.get('log_path', './logs')
+        log_path = home_path(
+            kwargs.get('log_path', '~/gn_socket/logs')
+        )
         log_level = kwargs.get('log_level', 'INFO')
         self.logger = LogFile(self.class_name,
                               station,
@@ -77,7 +72,6 @@ class BaseProtocol:
         host = self.host
         port = self.port
         loop = self.loop
-        address = (host, port)
         counter = 0
         while not self.status:
             if counter > self.max_try:
@@ -86,8 +80,9 @@ class BaseProtocol:
                 future_open_conn = asyncio.open_connection(
                     loop=loop,
                     host=host,
-                    port=port)  
-                (reader, writer) = await asyncio.wait_for(future_open_conn, timeout=self.timeout)
+                    port=port)
+                (reader, writer) = await asyncio.wait_for(
+                    future_open_conn, timeout=self.timeout)
                 idc = await self.set_reader_writer(reader, writer)
                 hb = await self.heart_beat(idc)
                 if hb:
@@ -96,16 +91,17 @@ class BaseProtocol:
                 else:
                     self.logger.error(hb)
             except asyncio.TimeoutError as te:
-                self.logger.exception("Tiempo fuera en intento de conexión %s, iteracion %d" %(te, counter))
+                self.logger.exception(
+                    f"Tiempo fuera en intento de conexión {te}, iteracion {counter}")
                 counter += 1
                 await asyncio.sleep(10+counter)
                 continue
             except socket.timeout as timeout:
                 self.on_blocking()
                 self.logger.error(
-                    "Error en conexión con %s:%s, error: %s, iteración %d" % (host, port, timeout, counter))
-                #print("Error de socket a GSOF en conexión %s" % timeout)
-                counter += 1                
+                    f"Error en conexión con {host}:{port}, error: {timeout}, iteración {counter}")
+                # print("Error de socket a GSOF en conexión %s" % timeout)
+                counter += 1
                 self.status = False
                 await asyncio.sleep(10+counter)
                 continue
@@ -113,27 +109,31 @@ class BaseProtocol:
                 # raise timeout
             except socket.error as e:
                 self.status = False
-                counter += 1                
+                counter += 1
                 self.on_blocking()
                 if e.errno == errno.ECONNREFUSED:
                     # print("Conexión rechazada en %s" %
                     #      self.station, file=sys.stderr)
-                    self.logger.exception("Error al conectar %s, station %s, iteración %d" %(e, self.station, counter))
+                    self.logger.exception(
+                        f"Error al conectar {e}, station {self.station}, iteración {counter}")
                     counter += 1
                     await asyncio.sleep(10+counter)
                 else:
                     # print("No se puede establecer conexión, de %s" %
                     #      self.station, file=sys.stderr)
-                    self.logger.exception("Otro tipo de error al conectar %s, station %s, iteración %d" %(e, self.station, counter))
-                    counter += 1                    
+                    self.logger.exception(
+                        f"Otro tipo de error al conectar {e}, station {self.station}, iteración {counter}")
+                    counter += 1
                     await asyncio.sleep(10+counter)
                 continue
             except (ConnectionResetError, ConnectionAbortedError) as conn_error:
-                self.logger.exception("Excepción por desconexión %s"%conn_error)
-                continue                
+                self.logger.exception(
+                    f"Excepción por desconexión {conn_error}")
+                continue
             except Exception as e:
-                print("Excepción no considerada")
-                self.logger.exception("Excepción no considerada %s"%e)
+                msg = f"Excepción no considerada e"
+                print(msg)
+                self.logger.exception(msg)
                 continue
             await asyncio.sleep(10+counter)
 
@@ -141,7 +141,6 @@ class BaseProtocol:
 
     # callback for create server:
 
-
     async def heart_beat(self, idc):
         tnow = now()
         if idc in self.clients.keys():
@@ -153,38 +152,44 @@ class BaseProtocol:
             if not closing and extra_info and not at_eof:
                 return True
             else:
-                print("Fail heart beat to %s, at %s" %(self.station, tnow))
-                msg_error = "Closing %s, extra_info %s, at_eof %s" %(closing, extra_info,at_eof)
+                msg_error = f"Closing {closing}, extra_info {extra_info}, at_eof {at_eof}"
                 print(msg_error)
                 self.logger.error(msg_error)
-                self.logger.error("no heart_beat, at %s" %tnow)
+                self.logger.error(f"no heart_beat, at {tnow}")
                 try:
                     await wait_for(self.close(idc), timeout=10)
                 except asyncio.TimeoutError as te:
-                    self.logger.exception("Tiempo fuera en intento de cerrar conexión %s, station %s" %(te, self.station))
+                    self.logger.exception(
+                        f"Tiempo fuera en intento de cerrar conexión {te}, station {self.station}")
                     await asyncio.sleep(10)
-                except ascyncio.IncompletereadError as e:
-                    self.logger.exception("Excepción por lectura incomplete  %s, station %s"%(e, self.station))
+                except asyncio.IncompletereadError as e:
+                    self.logger.exception(
+                        f"Excepción por lectura incomplete  {e}, station {self.station}")
                     await asyncio.sleep(10)
-                except ascyncio.CanceledError as e:
-                    self.logger.exception("Excepción por error de cancelación  %s, station %s"%(e, self.station))
+                except asyncio.CanceledError as e:
+                    self.logger.exception(
+                        "Excepción por error de cancelación  {e}, station {self.station}")
                     await asyncio.sleep(10)
                 except (ConnectionResetError, ConnectionAbortedError) as conn_error:
-                    self.logger.exception("Excepción por desconexión %s, station %s"%(conn_error, self.station))
-                    await asyncio.sleep(10)                    
-                except Exception as e:
-                    print("Excepción no considerada, %s"%e)
-                    self.logger.exception("Excepción no considerada %s, station %s"%(e, self.station))
+                    self.logger.exception(
+                        "Excepción por desconexión {conn_error}, station {self.station}")
                     await asyncio.sleep(10)
-                self.logger.exception("Cerrando correctamente la conexión, por no heartbeat")
+                except Exception as e:
+                    print(f"Excepción no considerada, {e}")
+                    self.logger.exception(
+                        f"Excepción no considerada {e}, station {self.station}")
+                    await asyncio.sleep(10)
+                self.logger.exception(
+                    "Cerrando correctamente la conexión, por no heartbeat")
                 self.status = False
                 return False
         else:
-            self.logger.error("no heart_beat, idc %s not client, code station %s" % (idc, self.station))
+            self.logger.error(
+                "no heart_beat, idc %s not client, code station %s" % (idc, self.station))
             await self.close(idc)
             self.status = False
             return False
- 
+
     def info(self, idc):
         if self.clients:
             writer = self.clients[idc]['writer']
@@ -231,17 +236,20 @@ class BaseProtocol:
         try:
             await wait_for(writer.wait_closed(), timeout=10)
         except asyncio.TimeoutError as te:
-            print("Close->Error Timeout al leer %d bytes en %s" %(n, self.station))
-            self.logger.exception("Station %s, Tiempo fuera al leer en readbytes, %s"%(self.station,te))
+            print(f"Close->Error Timeout al leer {te} bytes en {self.station}")
+            self.logger.exception(
+                f"Station {self.station}, Tiempo fuera al leer en readbytes, {te}")
         except asyncio.IncompleteReadError as ir:
-            print("Close_>Incomplete read, station %s" %self.station, reader, n)
-            self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(n, self.station,ir))
+            print("Close_>Incomplete read, station {self.station}")
+            self.logger.exception(
+                f"Station {self.station}, Tiempo fuera al no poder leer en close, {ir}")
         except (ConnectionResetError, ConnectionAbortedError) as conn_error:
-            self.logger.exception("Close->Excepción por desconexión al intentar leer %s"%conn_error)
+            self.logger.exception(
+                f"Close->Excepción por desconexión al intentar leer {conn_error}")
         except Exception as e:
             print("Excepción no considerada")
-            self.logger.exception("Close->Excepción no considerada al intentar leer%s"%e)
-
+            self.logger.exception(
+                f"Close->Excepción no considerada al intentar leer e")
 
     async def stop(self):
         for idc in self.clients:
@@ -250,27 +258,42 @@ class BaseProtocol:
     async def readbytes(self, reader, n):
         future = reader.readexactly(n)
         try:
-            result = await wait_for(future, timeout=self.timeout)
+            timeout = self.timeout
+            if n > 1:
+                timeout = timeout*n
+            result = await wait_for(future, timeout=timeout)
             return result
+        except BrokenPipeError as be:
+            print("readbytes", f"Error broken pip {be}")
+            return b''
+        except asyncio.IncompleteReadError as ir:
+            print(
+                f"Error por lectura incomplete al leer {n} bytes en {self.station}")
+            self.logger.exception(
+                f"Station {self.station}, lectura incomplete al leer en readbytes, error: {ir}")
         except asyncio.TimeoutError as te:
-            print("Error Timeout al leer %d bytes en %s" %(n, self.station))
-            self.logger.exception("Station %s, Tiempo fuera al leer en readbytes, %s"%(self.station,te))
+            print(f"Error Timeout al leer {n} bytes en {self.station}")
+            self.logger.exception(
+                f"Station {self.station}, Tiempo fuera al leer en readbytes, {te}")
             if self.raise_timeout:
                 raise te
             else:
-                return None
+                return b''
         except asyncio.IncompleteReadError as ir:
-            print("Incomplete read, station %s" %self.station, reader, n)
-            self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(n, self.station,ir))
-            return None
+            print(f"Incomplete read, station {self.station}")
+            self.logger.exception(
+                f"Station {self.station}, Tiempo fuera al no poder leer en readbytes {n} bytes, {ir}")
+            return b''
         except (ConnectionResetError, ConnectionAbortedError) as conn_error:
-            self.logger.exception("Excepción por desconexión al intentar leer %s"%conn_error)
-            return None
+            self.logger.exception(
+                f"Excepción por desconexión al intentar leer {conn_error}")
+            return b''
         except Exception as e:
             print("Excepción no considerada")
-            self.logger.exception("Excepción no considerada al intentar leer%s"%e)
-            return None
-        
+            self.logger.exception(
+                "Excepción no considerada al intentar leer {e}")
+            return b''
+
     async def get_message_header(self, idc):
         self.idc = idc
 
