@@ -79,7 +79,7 @@ class Eryo(BaseProtocol):
         self.rec_dict = {}
         self.batt_status = 0
         self.tables = ERYO_TABLE_NAMES
-            
+
     async def get_records(self):
         """
         Obtener bytes y traducir a un msg ERYO
@@ -93,7 +93,7 @@ class Eryo(BaseProtocol):
         t0 = time.time()
         try:
             if writer.transport.is_closing():
-                self.logger.error("La conexión se cerró %s" % writer)
+                self.logger.error(f"La conexión se cerró {writer}")
                 self.status = False
                 raise Exception("Conexión perdida")
             try:
@@ -105,13 +105,13 @@ class Eryo(BaseProtocol):
                 msg = {}
                 position = 0
                 while not done:
-                    byte_a = await shield(self.readbytes(reader,1))
+                    byte_a = await shield(self.readbytes(reader, 1))
                     while byte_a != sync_marker_first:
-                        byte_a = await shield(self.readbytes(reader,1))
-                    byte_b = await shield(self.readbytes(reader,1))
+                        byte_a = await shield(self.readbytes(reader, 1))
+                    byte_b = await shield(self.readbytes(reader, 1))
                     if byte_b == sync_marker_second:
                         # read next 3 bytes
-                        resto_header = await shield(self.readbytes(reader,3))
+                        resto_header = await shield(self.readbytes(reader, 3))
                         suma_bytes += 5
                         header = byte_a+byte_b+resto_header
                         data += header
@@ -121,7 +121,7 @@ class Eryo(BaseProtocol):
                         msg["ERYO_HEADER"] = data_dict
                         # POSITION_BLOCK
                         byte_count = data_dict.get("BYTE_COUNT")
-                        all_bytes = await shield(self.readbytes(reader,byte_count-5))
+                        all_bytes = await shield(self.readbytes(reader, byte_count-5))
                         data += all_bytes
                         key_2 = "POSITION_BLOCK"
                         PB_bytes = TABLES_SIZES.get(key_2)
@@ -193,18 +193,21 @@ class Eryo(BaseProtocol):
                         done = checksum_msg == chsum
                 return done, msg
             except asyncio.TimeoutError as te:
-                print("Timeout error on Eryo %s, error %s"%(self.station, te))
-                self.logger.exception("Get message records TimeoutError, %s"%te)
-                return False,{}                
+                print(f"Timeout error on Eryo {self.station}, error {te}")
+                self.logger.exception(
+                    f"Get message records TimeoutError, {te}")
+                return False, {}
             except asyncio.IncompleteReadError as ir:
-                print("Incomplete read on get records header, ERYO, station %s" %self.station, reader, n)
-                self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(n, self.station,ir))
+                print(
+                    f"Incomplete read on get records header, ERYO, station {self.station}")
+                self.logger.exception(
+                    f"Station {self.station}, Tiempo fuera al no poder leer en readbytes {n} bytes, {ir}")
                 if self.raise_incompleteread:
                     raise ir
-                return False,{}
+                return False, {}
             except socket.timeout as timeout:
                 self.logger.warning(
-                    "La conexión se cerró, socket timeout %s" % timeout)
+                    f"La conexión se cerró, socket timeout {timeout}")
                 self.on_blocking()
                 self.logger.exception()
                 self.status = False
@@ -212,11 +215,10 @@ class Eryo(BaseProtocol):
                 return False, {}
             except Exception as ex:
                 self.logger.error(
-                    "La conexión se cerró, error en comunicación %s" % ex)
+                    f"La conexión se cerró, error en comunicación {ex}")
                 self.close(idc)
                 self.on_blocking()
-                info = "Error %s en estación %s. Encabezado con data %s" % (
-                    ex, self.station, data)
+                info = f"Error {ex} en estación {self.station}. Encabezado con data {data}"
                 self.logger.info(info)
                 self.logger.error(ex)
                 self.status = False
@@ -224,7 +226,7 @@ class Eryo(BaseProtocol):
                 return False, {}
         except socket.timeout as timeout:
             self.logger.warning(
-                "La conexión se cerró, socket timeout %s" % timeout)
+                f"La conexión se cerró, socket timeout {timeout}")
             self.on_blocking()
             self.logger.exception()
             self.status = False
@@ -232,17 +234,15 @@ class Eryo(BaseProtocol):
             return False, {}
         except Exception as ex:
             self.logger.error(
-                "La conexión se cerró, error en comunicación %s" % ex)
+                f"La conexión se cerró, error en comunicación {ex}")
             self.close(idc)
             self.on_blocking()
-            info = "Error %s en estación %s. Encabezado con data %s" % (
-                ex, self.station, data)
-            print(info)
+            info = f"Error {ex} en estación {self.station}. Encabezado con data {data}"
             self.logger.info(info)
             self.logger.error(ex)
             self.status = False
             await asyncio.sleep(.1)
-            return False,{}
+            return False, {}
 
     async def get_message_header(self, idc):
         self.select_idc = idc
