@@ -1,4 +1,5 @@
-from struct import unpack
+from struct import unpack, error as struct_error
+
 import socket
 from asyncio import shield
 import asyncio
@@ -138,17 +139,21 @@ class Gsof(BaseProtocol):
             self.on_blocking()
             raise ex
 
-    async def get_records(self):
+    async def get_records(self, idc='', ids=''):
         msg = {}
         while self.msg_bytes:
             # READ THE FIRST TWO BYTES FROM RECORD HEADER
             try:
                 record_type, record_length = unpack('>2B', self.msg_bytes[0:2])
+            except struct_error as unpack_error:
+                self.status = False
+                self.logger.exception(f"Error en hacer unpack {unpack_error} (error)")
+                raise unpack_error
             except Exception as ex:
                 self.status = False
                 qex = f"Error {ex} en estación {self.station}, tabla Header"
                 self.logger.debug(qex)
-                return False, {}
+                raise ex
             self.msg_bytes = self.msg_bytes[2:]
             try:
                 msg_table = self.select_record(record_type, record_length)
@@ -160,7 +165,8 @@ class Gsof(BaseProtocol):
                 self.logger.error(
                     f"Reconectando debido a error en mensaje, luego de desconexión, {ex}")
                 self.on_blocking()
-                return False, {}
+                self.logger.error(f"Levantando error a ...Clliente {idc} Station ID: {ids}")
+                raise ex
         msg["HEADER"] = self.msg_dict
         done = self.checksum
         return done, msg
@@ -182,6 +188,10 @@ class Gsof(BaseProtocol):
                     msg['TIMESTAMP'] = timestamp
                     self.rec_dict.update({table_name: msg})
                     self.msg_bytes = self.msg_bytes[record_length:]
+                except struct_error as unpack_error:
+                    self.status = False
+                    self.logger.exception(f"Error en hacer unpack {unpack_error} (error)")
+                    raise unpack_error
                 except Exception as ex:
                     self.status = False
                     self.logger.exception(f"Error al hacer unpack {ex}")
@@ -193,6 +203,10 @@ class Gsof(BaseProtocol):
                 try:
                     code = rec_input[record_type][0]
                     NUM_OF_SVS = unpack(code, bNUM)  # char-> pass to int
+                except struct_error as unpack_error:
+                    self.status = False
+                    self.logger.exception(f"Error en hacer unpack {unpack_error} (error)")
+                    raise unpack_error
                 except Exception as ex:
                     self.status = False
                     qex = "Error %s en estación %s, tabla %s" % (
@@ -212,6 +226,10 @@ class Gsof(BaseProtocol):
                         msg_k = dict(list(zip(rec_field_names, rec_values)))
                         msg_k['TIMESTAMP'] = timestamp
                         msg.append(msg_k)
+                    except struct_error as unpack_error:
+                        self.status = False
+                        self.logger.exception(f"Error en hacer unpack {unpack_error} (error)")
+                        raise unpack_error
                     except Exception as ex:
                         self.status = False
                         self.logger.debug(ex)
